@@ -58,7 +58,7 @@ matrix_to_network.matrix <- function(
   ...
   ) {
   
-  matrix_to_network.(
+  matrix_to_network_cpp(
     x = list(x),
     directed = directed,
     hyper = hyper,
@@ -125,7 +125,7 @@ matrix_to_network.list <- function(
   res <- vector("list", nnets(x))
   for (i in seq_along(chunks$from)) {
     
-    res[chunks$from[i]:chunks$to[i]] <- matrix_to_network.(
+    res[chunks$from[i]:chunks$to[i]] <- matrix_to_network_cpp(
       x         = x[chunks$from[i]:chunks$to[i]],
       directed  = directed[chunks$from[i]:chunks$to[i]],
       hyper     = hyper[chunks$from[i]:chunks$to[i]],
@@ -152,7 +152,7 @@ matrix_to_network.list <- function(
 #'   if (!all(sapply(x, inherits, "network")))
 #'     stop("`x` must be an object of class network.", call. = FALSE)
 #'   
-#'   add_vertex_attr.(x, attrvalue, attrname, names(x[[1]]$val[[1]]))
+#'   add_vertex_attr_cpp(x, attrvalue, attrname, names(x[[1]]$val[[1]]))
 #'   
 #'   # x
 #'   
